==> easyapi-0.8.5.9-sources.jar: cn/easyutil/easyapi/mybatis/MybatisUtil.java <==
package cn.easyutil.easyapi.mybatis;

import com.baomidou.mybatisplus.annotation.DbType;
import com.baomidou.mybatisplus.core.MybatisConfiguration;
import com.baomidou.mybatisplus.core.config.GlobalConfig;
import com.baomidou.mybatisplus.core.toolkit.GlobalConfigUtils;
import com.baomidou.mybatisplus.extension.plugins.MybatisPlusInterceptor;
import com.baomidou.mybatisplus.extension.plugins.inner.PaginationInnerInterceptor;
import com.baomidou.mybatisplus.extension.spring.MybatisSqlSessionFactoryBean;
import org.apache.ibatis.logging.nologging.NoLoggingImpl;
import org.apache.ibatis.logging.stdout.StdOutImpl;
import org.apache.ibatis.mapping.Environment;
import org.apache.ibatis.session.SqlSessionManager;
import org.apache.ibatis.transaction.jdbc.JdbcTransactionFactory;

import javax.sql.DataSource;

public class MybatisUtil {

    private static SqlSessionManager sqlSessionManager = null;

    public synchronized static void init(DataSource dataSource,boolean showSql, Class<?>...mappers) {
        if (sqlSessionManager == null) {
            MybatisSqlSessionFactoryBean mfb = new MybatisSqlSessionFactoryBean();
            mfb.setDataSource(dataSource);
            MybatisConfiguration conf = new MybatisConfiguration();
            conf.setLogImpl(NoLoggingImpl.class);
            if(showSql){
                conf.setLogImpl(StdOutImpl.class);
            }
            Environment env = new Environment.Builder("datasource").dataSource(dataSource).transactionFactory(new JdbcTransactionFactory()).build();
            conf.setEnvironment(env);
            mfb.setConfiguration(conf);
            conf.setMapUnderscoreToCamelCase(true);
            MybatisPlusInterceptor interceptor = new MybatisPlusInterceptor();
            interceptor.addInnerInterceptor(new PaginationInnerInterceptor(DbType.H2));
            mfb.setPlugins(interceptor);
            GlobalConfig defaults = GlobalConfigUtils.defaults();
            defaults.setBanner(false);
            mfb.setGlobalConfig(defaults);
            for (Class<?> mapper : mappers) {
                conf.addMapper(mapper);
            }
            conf.addMapper(SqlExecMapper.class);
            try {
                sqlSessionManager = SqlSessionManager.newInstance(mfb.getObject());
            } catch (Exception e) {
                sqlSessionManager = null;
            }
        }
    }

    public static <T> T getMapper(Class<T> clazz) {
        return sqlSessionManager.getMapper(clazz);
    }
}

==> easyapi-0.8.9-sources.jar: cn/easyutil/easyapi/mybatis/MybatisUtil.java <==
package cn.easyutil.easyapi.mybatis;

import com.baomidou.mybatisplus.annotation.DbType;
import com.baomidou.mybatisplus.core.MybatisConfiguration;
import com.baomidou.mybatisplus.core.config.GlobalConfig;
import com.baomidou.mybatisplus.core.incrementer.DefaultIdentifierGenerator;
import com.baomidou.mybatisplus.core.toolkit.GlobalConfigUtils;
import com.baomidou.mybatisplus.extension.plugins.MybatisPlusInterceptor;
import com.baomidou.mybatisplus.extension.plugins.inner.PaginationInnerInterceptor;
import com.baomidou.mybatisplus.extension.spring.MybatisSqlSessionFactoryBean;
import org.apache.ibatis.logging.nologging.NoLoggingImpl;
import org.apache.ibatis.logging.stdout.StdOutImpl;
import org.apache.ibatis.mapping.Environment;
import org.apache.ibatis.session.SqlSessionManager;
import org.apache.ibatis.transaction.jdbc.JdbcTransactionFactory;

import javax.sql.DataSource;
import java.util.Random;

public class MybatisUtil {

    private static SqlSessionManager sqlSessionManager = null;

    public synchronized static void init(DataSource dataSource,boolean showSql, Class<?>...mappers) {
        if (sqlSessionManager == null) {
            MybatisSqlSessionFactoryBean mfb = new MybatisSqlSessionFactoryBean();
            mfb.setDataSource(dataSource);
            MybatisConfiguration conf = new MybatisConfiguration();
            conf.setLogImpl(NoLoggingImpl.class);
            if(showSql){
                conf.setLogImpl(StdOutImpl.class);
            }
            Environment env = new Environment.Builder("datasource").dataSource(dataSource).transactionFactory(new JdbcTransactionFactory()).build();
            conf.setEnvironment(env);
            mfb.setConfiguration(conf);
            conf.setMapUnderscoreToCamelCase(true);
            MybatisPlusInterceptor interceptor = new MybatisPlusInterceptor();
            interceptor.addInnerInterceptor(new PaginationInnerInterceptor(DbType.H2));
            mfb.setPlugins(interceptor);
            GlobalConfig defaults = GlobalConfigUtils.defaults();
            defaults.setBanner(false);
            int workId = new Random().nextInt(30);
            int tranceId = new Random().nextInt(30);
            defaults.setIdentifierGenerator(new DefaultIdentifierGenerator(workId,tranceId));
            mfb.setGlobalConfig(defaults);
            for (Class<?> mapper : mappers) {
                conf.addMapper(mapper);
            }
            conf.addMapper(SqlExecMapper.class);
            try {
                sqlSessionManager = SqlSessionManager.newInstance(mfb.getObject());
            } catch (Exception e) {
                sqlSessionManager = null;
            }
        }
    }

    public static <T> T getMapper(Class<T> clazz) {
        return sqlSessionManager.getMapper(clazz);
    }
}
